import React from 'react';
import { CssBaseline } from '@material-ui/core';
import { MuiThemeProvider } from '@material-ui/core/styles';
import App from './App';
import AppStateProvider, { useAppState } from './state';
import ErrorDialog from './components/ErrorDialog/ErrorDialog';
import theme from './theme';
import './types';
import { ChatProvider } from './components/ChatProvider';
import { ParticipantProvider } from './components/ParticipantProvider';
import { VideoProvider } from './components/VideoProvider';
import useConnectionOptions from './utils/useConnectionOptions/useConnectionOptions';
import UnsupportedBrowserWarning from './components/UnsupportedBrowserWarning/UnsupportedBrowserWarning';

const VideoApp = () => {
  const {
    error,
    setError
  } = useAppState();
  const connectionOptions = useConnectionOptions();
  return /*#__PURE__*/React.createElement(VideoProvider, {
    options: connectionOptions,
    onError: setError
  }, /*#__PURE__*/React.createElement(ErrorDialog, {
    dismissError: () => setError(null),
    error: error
  }), /*#__PURE__*/React.createElement(ParticipantProvider, null, /*#__PURE__*/React.createElement(ChatProvider, null, /*#__PURE__*/React.createElement(App, null))));
};

export const VideoConference = () => /*#__PURE__*/React.createElement(MuiThemeProvider, {
  theme: theme
}, /*#__PURE__*/React.createElement(CssBaseline, null), /*#__PURE__*/React.createElement(UnsupportedBrowserWarning, null, /*#__PURE__*/React.createElement(AppStateProvider, null, /*#__PURE__*/React.createElement(VideoApp, null))));