import React from 'react';
import AudioLevelIndicator from '../../AudioLevelIndicator/AudioLevelIndicator';
import { FormControl, MenuItem, Typography, Select, Grid } from '@material-ui/core';
import { SELECTED_AUDIO_INPUT_KEY } from '../../../constants';
import useDevices from '../../../hooks/useDevices/useDevices';
import useMediaStreamTrack from '../../../hooks/useMediaStreamTrack/useMediaStreamTrack';
import useVideoContext from '../../../hooks/useVideoContext/useVideoContext';
export default function AudioInputList() {
  const {
    audioInputDevices
  } = useDevices();
  const {
    localTracks
  } = useVideoContext();
  const localAudioTrack = localTracks.find(track => track.kind === 'audio');
  const mediaStreamTrack = useMediaStreamTrack(localAudioTrack);
  const localAudioInputDeviceId = mediaStreamTrack?.getSettings().deviceId;

  function replaceTrack(newDeviceId) {
    window.localStorage.setItem(SELECTED_AUDIO_INPUT_KEY, newDeviceId);
    localAudioTrack?.restart({
      deviceId: {
        exact: newDeviceId
      }
    });
  }

  return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Typography, {
    variant: "subtitle2",
    gutterBottom: true
  }, "Audio Input"), /*#__PURE__*/React.createElement(Grid, {
    container: true,
    alignItems: "center",
    justifyContent: "space-between"
  }, /*#__PURE__*/React.createElement("div", {
    className: "inputSelect"
  }, audioInputDevices.length > 1 ? /*#__PURE__*/React.createElement(FormControl, {
    fullWidth: true
  }, /*#__PURE__*/React.createElement(Select, {
    onChange: e => replaceTrack(e.target.value),
    value: localAudioInputDeviceId || '',
    variant: "outlined"
  }, audioInputDevices.map(device => /*#__PURE__*/React.createElement(MenuItem, {
    value: device.deviceId,
    key: device.deviceId
  }, device.label)))) : /*#__PURE__*/React.createElement(Typography, null, localAudioTrack?.mediaStreamTrack.label || 'No Local Audio')), /*#__PURE__*/React.createElement(AudioLevelIndicator, {
    audioTrack: localAudioTrack,
    color: "black"
  })));
}