import React, { useState } from 'react';
import { useAppState } from '../../state';
import Button from '@material-ui/core/Button';
import ErrorOutlineIcon from '@material-ui/icons/ErrorOutline';
import Grid from '@material-ui/core/Grid';
import { ReactComponent as GoogleLogo } from './google-logo.svg';
import { InputLabel } from '@material-ui/core';
import IntroContainer from '../IntroContainer/IntroContainer';
import TextField from '@material-ui/core/TextField';
import Typography from '@material-ui/core/Typography';
import { makeStyles } from '@material-ui/core/styles';
import { useLocation, useHistory } from 'react-router-dom';
const useStyles = makeStyles(theme => ({
  googleButton: {
    background: 'white',
    color: 'rgb(0, 94, 166)',
    borderRadius: '4px',
    border: '2px solid rgb(2, 122, 197)',
    margin: '1.8em 0 0.7em',
    textTransform: 'none',
    boxShadow: 'none',
    padding: '0.3em 1em',
    [theme.breakpoints.down('sm')]: {
      width: '100%'
    },
    '&:hover': {
      background: 'white',
      boxShadow: 'none'
    }
  },
  errorMessage: {
    color: 'red',
    display: 'flex',
    alignItems: 'center',
    margin: '1em 0 0.2em',
    '& svg': {
      marginRight: '0.4em'
    }
  },
  gutterBottom: {
    marginBottom: '1em'
  },
  passcodeContainer: {
    minHeight: '120px'
  },
  submitButton: {
    [theme.breakpoints.down('sm')]: {
      width: '100%'
    }
  }
}));
export default function LoginPage() {
  const classes = useStyles();
  const {
    signIn,
    user,
    isAuthReady
  } = useAppState();
  const history = useHistory();
  const location = useLocation();
  const [passcode, setPasscode] = useState('');
  const [authError, setAuthError] = useState(null);
  const isAuthEnabled = Boolean(process.env.REACT_APP_SET_AUTH);

  const login = () => {
    setAuthError(null);
    signIn?.(passcode).then(() => {
      history.replace(location?.state?.from || {
        pathname: '/'
      });
    }).catch(err => setAuthError(err));
  };

  const handleSubmit = e => {
    e.preventDefault();
    login();
  };

  if (user || !isAuthEnabled) {
    history.replace('/');
  }

  if (!isAuthReady) {
    return null;
  }

  return /*#__PURE__*/React.createElement(IntroContainer, null, process.env.REACT_APP_SET_AUTH === 'firebase' && /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Typography, {
    variant: "h5",
    className: classes.gutterBottom
  }, "Sign in to join a room"), /*#__PURE__*/React.createElement(Typography, {
    variant: "body1"
  }, "Sign in using your Twilio Google Account"), /*#__PURE__*/React.createElement(Button, {
    variant: "contained",
    className: classes.googleButton,
    onClick: login,
    startIcon: /*#__PURE__*/React.createElement(GoogleLogo, null)
  }, "Sign in with Google")), process.env.REACT_APP_SET_AUTH === 'passcode' && /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Typography, {
    variant: "h5",
    className: classes.gutterBottom
  }, "Enter passcode to join a room"), /*#__PURE__*/React.createElement("form", {
    onSubmit: handleSubmit
  }, /*#__PURE__*/React.createElement(Grid, {
    container: true,
    justifyContent: "space-between"
  }, /*#__PURE__*/React.createElement("div", {
    className: classes.passcodeContainer
  }, /*#__PURE__*/React.createElement(InputLabel, {
    shrink: true,
    htmlFor: "input-passcode"
  }, "Passcode"), /*#__PURE__*/React.createElement(TextField, {
    id: "input-passcode",
    onChange: e => setPasscode(e.target.value),
    type: "password",
    variant: "outlined",
    size: "small"
  }), /*#__PURE__*/React.createElement("div", null, authError && /*#__PURE__*/React.createElement(Typography, {
    variant: "caption",
    className: classes.errorMessage
  }, /*#__PURE__*/React.createElement(ErrorOutlineIcon, null), authError.message)))), /*#__PURE__*/React.createElement(Grid, {
    container: true,
    justifyContent: "flex-end"
  }, /*#__PURE__*/React.createElement(Button, {
    variant: "contained",
    color: "primary",
    type: "submit",
    disabled: !passcode.length,
    className: classes.submitButton
  }, "Submit")))));
}