import React, { useState, useRef } from 'react';
import AboutDialog from '../../AboutDialog/AboutDialog';
import BackgroundIcon from '../../../icons/BackgroundIcon';
import CollaborationViewIcon from '@material-ui/icons/AccountBox';
import DeviceSelectionDialog from '../../DeviceSelectionDialog/DeviceSelectionDialog';
import ExpandMoreIcon from '@material-ui/icons/ExpandMore';
import GridViewIcon from '@material-ui/icons/Apps';
import InfoIconOutlined from '../../../icons/InfoIconOutlined';
import MoreIcon from '@material-ui/icons/MoreVert';
import StartRecordingIcon from '../../../icons/StartRecordingIcon';
import StopRecordingIcon from '../../../icons/StopRecordingIcon';
import SearchIcon from '@material-ui/icons/Search';
import SettingsIcon from '../../../icons/SettingsIcon';
import { Button, styled, useMediaQuery, Menu as MenuContainer, MenuItem, Typography } from '@material-ui/core';
import { isSupported } from '@twilio/video-processors';
import { useAppState } from '../../../state';
import useChatContext from '../../../hooks/useChatContext/useChatContext';
import useIsRecording from '../../../hooks/useIsRecording/useIsRecording';
import useVideoContext from '../../../hooks/useVideoContext/useVideoContext';
import FlipCameraIcon from '../../../icons/FlipCameraIcon';
import useFlipCameraToggle from '../../../hooks/useFlipCameraToggle/useFlipCameraToggle';
import { VideoRoomMonitor } from '@twilio/video-room-monitor';
export const IconContainer = styled('div')({
  display: 'flex',
  justifyContent: 'center',
  width: '1.5em',
  marginRight: '0.3em'
});
export default function Menu(props) {
  const isMobile = useMediaQuery(theme => theme.breakpoints.down('sm'));
  const [aboutOpen, setAboutOpen] = useState(false);
  const [menuOpen, setMenuOpen] = useState(false);
  const [settingsOpen, setSettingsOpen] = useState(false);
  const {
    isFetching,
    updateRecordingRules,
    roomType,
    setIsGalleryViewActive,
    isGalleryViewActive
  } = useAppState();
  const {
    setIsChatWindowOpen
  } = useChatContext();
  const isRecording = useIsRecording();
  const {
    room,
    setIsBackgroundSelectionOpen
  } = useVideoContext();
  const anchorRef = useRef(null);
  const {
    flipCameraDisabled,
    toggleFacingMode,
    flipCameraSupported
  } = useFlipCameraToggle();
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Button, {
    onClick: () => setMenuOpen(isOpen => !isOpen),
    ref: anchorRef,
    className: props.buttonClassName,
    "data-cy-more-button": true
  }, isMobile ? /*#__PURE__*/React.createElement(MoreIcon, null) : /*#__PURE__*/React.createElement(React.Fragment, null, "More", /*#__PURE__*/React.createElement(ExpandMoreIcon, null))), /*#__PURE__*/React.createElement(MenuContainer, {
    open: menuOpen,
    onClose: () => setMenuOpen(isOpen => !isOpen),
    anchorEl: anchorRef.current,
    anchorOrigin: {
      vertical: 'top',
      horizontal: 'left'
    },
    transformOrigin: {
      vertical: isMobile ? -55 : 'bottom',
      horizontal: 'center'
    }
  }, /*#__PURE__*/React.createElement(MenuItem, {
    onClick: () => setSettingsOpen(true)
  }, /*#__PURE__*/React.createElement(IconContainer, null, /*#__PURE__*/React.createElement(SettingsIcon, null)), /*#__PURE__*/React.createElement(Typography, {
    variant: "body1"
  }, "Audio and Video Settings")), isSupported && /*#__PURE__*/React.createElement(MenuItem, {
    onClick: () => {
      setIsBackgroundSelectionOpen(true);
      setIsChatWindowOpen(false);
      setMenuOpen(false);
    }
  }, /*#__PURE__*/React.createElement(IconContainer, null, /*#__PURE__*/React.createElement(BackgroundIcon, null)), /*#__PURE__*/React.createElement(Typography, {
    variant: "body1"
  }, "Backgrounds")), flipCameraSupported && /*#__PURE__*/React.createElement(MenuItem, {
    disabled: flipCameraDisabled,
    onClick: toggleFacingMode
  }, /*#__PURE__*/React.createElement(IconContainer, null, /*#__PURE__*/React.createElement(FlipCameraIcon, null)), /*#__PURE__*/React.createElement(Typography, {
    variant: "body1"
  }, "Flip Camera")), roomType !== 'peer-to-peer' && roomType !== 'go' && /*#__PURE__*/React.createElement(MenuItem, {
    disabled: isFetching,
    onClick: () => {
      setMenuOpen(false);

      if (isRecording) {
        updateRecordingRules(room.sid, [{
          type: 'exclude',
          all: true
        }]);
      } else {
        updateRecordingRules(room.sid, [{
          type: 'include',
          all: true
        }]);
      }
    },
    "data-cy-recording-button": true
  }, /*#__PURE__*/React.createElement(IconContainer, null, isRecording ? /*#__PURE__*/React.createElement(StopRecordingIcon, null) : /*#__PURE__*/React.createElement(StartRecordingIcon, null)), /*#__PURE__*/React.createElement(Typography, {
    variant: "body1"
  }, isRecording ? 'Stop' : 'Start', " Recording")), /*#__PURE__*/React.createElement(MenuItem, {
    onClick: () => {
      VideoRoomMonitor.toggleMonitor();
      setMenuOpen(false);
    }
  }, /*#__PURE__*/React.createElement(IconContainer, null, /*#__PURE__*/React.createElement(SearchIcon, {
    style: {
      fill: '#707578',
      width: '0.9em'
    }
  })), /*#__PURE__*/React.createElement(Typography, {
    variant: "body1"
  }, "Room Monitor")), /*#__PURE__*/React.createElement(MenuItem, {
    onClick: () => {
      setIsGalleryViewActive(isGallery => !isGallery);
      setMenuOpen(false);
    }
  }, /*#__PURE__*/React.createElement(IconContainer, null, isGalleryViewActive ? /*#__PURE__*/React.createElement(CollaborationViewIcon, {
    style: {
      fill: '#707578',
      width: '0.9em'
    }
  }) : /*#__PURE__*/React.createElement(GridViewIcon, {
    style: {
      fill: '#707578',
      width: '0.9em'
    }
  })), /*#__PURE__*/React.createElement(Typography, {
    variant: "body1"
  }, isGalleryViewActive ? 'Speaker View' : 'Gallery View')), /*#__PURE__*/React.createElement(MenuItem, {
    onClick: () => setAboutOpen(true)
  }, /*#__PURE__*/React.createElement(IconContainer, null, /*#__PURE__*/React.createElement(InfoIconOutlined, null)), /*#__PURE__*/React.createElement(Typography, {
    variant: "body1"
  }, "About"))), /*#__PURE__*/React.createElement(AboutDialog, {
    open: aboutOpen,
    onClose: () => {
      setAboutOpen(false);
      setMenuOpen(false);
    }
  }), /*#__PURE__*/React.createElement(DeviceSelectionDialog, {
    open: settingsOpen,
    onClose: () => {
      setSettingsOpen(false);
      setMenuOpen(false);
    }
  }));
}