import React from 'react';
import { makeStyles, Typography, Grid, Button, Hidden } from '@material-ui/core';
import CircularProgress from '@material-ui/core/CircularProgress';
import LocalVideoPreview from './LocalVideoPreview/LocalVideoPreview';
import SettingsMenu from './SettingsMenu/SettingsMenu';
import { Steps } from '../PreJoinScreens';
import ToggleAudioButton from '../../Buttons/ToggleAudioButton/ToggleAudioButton';
import ToggleVideoButton from '../../Buttons/ToggleVideoButton/ToggleVideoButton';
import { useAppState } from '../../../state';
import useChatContext from '../../../hooks/useChatContext/useChatContext';
import useVideoContext from '../../../hooks/useVideoContext/useVideoContext';
const useStyles = makeStyles(theme => ({
  gutterBottom: {
    marginBottom: '1em'
  },
  marginTop: {
    marginTop: '1em'
  },
  deviceButton: {
    width: '100%',
    border: '2px solid #aaa',
    margin: '1em 0'
  },
  localPreviewContainer: {
    paddingRight: '2em',
    [theme.breakpoints.down('sm')]: {
      padding: '0 2.5em'
    }
  },
  joinButtons: {
    display: 'flex',
    justifyContent: 'space-between',
    [theme.breakpoints.down('sm')]: {
      flexDirection: 'column-reverse',
      width: '100%',
      '& button': {
        margin: '0.5em 0'
      }
    }
  },
  mobileButtonBar: {
    [theme.breakpoints.down('sm')]: {
      display: 'flex',
      justifyContent: 'space-between',
      margin: '1.5em 0 1em'
    }
  },
  mobileButton: {
    padding: '0.8em 0',
    margin: 0
  }
}));
export default function DeviceSelectionScreen({
  name,
  roomName,
  setStep
}) {
  const classes = useStyles();
  const {
    getToken,
    isFetching
  } = useAppState();
  const {
    connect: chatConnect
  } = useChatContext();
  const {
    connect: videoConnect,
    isAcquiringLocalTracks,
    isConnecting
  } = useVideoContext();
  const disableButtons = isFetching || isAcquiringLocalTracks || isConnecting;

  const handleJoin = () => {
    getToken(name, roomName).then(({
      token
    }) => {
      videoConnect(token);
      process.env.REACT_APP_DISABLE_TWILIO_CONVERSATIONS !== 'true' && chatConnect(token);
    });
  };

  if (isFetching || isConnecting) {
    return /*#__PURE__*/React.createElement(Grid, {
      container: true,
      justifyContent: "center",
      alignItems: "center",
      direction: "column",
      style: {
        height: '100%'
      }
    }, /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(CircularProgress, {
      variant: "indeterminate"
    })), /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Typography, {
      variant: "body2",
      style: {
        fontWeight: 'bold',
        fontSize: '16px'
      }
    }, "Joining Meeting")));
  }

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Typography, {
    variant: "h5",
    className: classes.gutterBottom
  }, "Join ", roomName), /*#__PURE__*/React.createElement(Grid, {
    container: true,
    justifyContent: "center"
  }, /*#__PURE__*/React.createElement(Grid, {
    item: true,
    md: 7,
    sm: 12,
    xs: 12
  }, /*#__PURE__*/React.createElement("div", {
    className: classes.localPreviewContainer
  }, /*#__PURE__*/React.createElement(LocalVideoPreview, {
    identity: name
  })), /*#__PURE__*/React.createElement("div", {
    className: classes.mobileButtonBar
  }, /*#__PURE__*/React.createElement(Hidden, {
    mdUp: true
  }, /*#__PURE__*/React.createElement(ToggleAudioButton, {
    className: classes.mobileButton,
    disabled: disableButtons
  }), /*#__PURE__*/React.createElement(ToggleVideoButton, {
    className: classes.mobileButton,
    disabled: disableButtons
  })), /*#__PURE__*/React.createElement(SettingsMenu, {
    mobileButtonClass: classes.mobileButton
  }))), /*#__PURE__*/React.createElement(Grid, {
    item: true,
    md: 5,
    sm: 12,
    xs: 12
  }, /*#__PURE__*/React.createElement(Grid, {
    container: true,
    direction: "column",
    justifyContent: "space-between",
    style: {
      height: '100%'
    }
  }, /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Hidden, {
    smDown: true
  }, /*#__PURE__*/React.createElement(ToggleAudioButton, {
    className: classes.deviceButton,
    disabled: disableButtons
  }), /*#__PURE__*/React.createElement(ToggleVideoButton, {
    className: classes.deviceButton,
    disabled: disableButtons
  }))), /*#__PURE__*/React.createElement("div", {
    className: classes.joinButtons
  }, /*#__PURE__*/React.createElement(Button, {
    variant: "outlined",
    color: "primary",
    onClick: () => setStep(Steps.roomNameStep)
  }, "Cancel"), /*#__PURE__*/React.createElement(Button, {
    variant: "contained",
    color: "primary",
    "data-cy-join-now": true,
    onClick: handleJoin,
    disabled: disableButtons
  }, "Join Now"))))));
}