import React, { useState, useRef } from 'react';
import Button from '@material-ui/core/Button';
import MenuContainer from '@material-ui/core/Menu';
import MenuItem from '@material-ui/core/MenuItem';
import MoreIcon from '@material-ui/icons/MoreVert';
import Typography from '@material-ui/core/Typography';
import { makeStyles, useMediaQuery } from '@material-ui/core';
import AboutDialog from '../../../AboutDialog/AboutDialog';
import ConnectionOptionsDialog from '../../../ConnectionOptionsDialog/ConnectionOptionsDialog';
import DeviceSelectionDialog from '../../../DeviceSelectionDialog/DeviceSelectionDialog';
import SettingsIcon from '../../../../icons/SettingsIcon';
import { useAppState } from '../../../../state';
const useStyles = makeStyles({
  settingsButton: {
    margin: '1.8em 0 0'
  }
});
export default function SettingsMenu({
  mobileButtonClass
}) {
  const classes = useStyles();
  const {
    roomType
  } = useAppState();
  const isMobile = useMediaQuery(theme => theme.breakpoints.down('sm'));
  const [menuOpen, setMenuOpen] = useState(false);
  const [aboutOpen, setAboutOpen] = useState(false);
  const [deviceSettingsOpen, setDeviceSettingsOpen] = useState(false);
  const [connectionSettingsOpen, setConnectionSettingsOpen] = useState(false);
  const anchorRef = useRef(null);
  return /*#__PURE__*/React.createElement(React.Fragment, null, isMobile ? /*#__PURE__*/React.createElement(Button, {
    ref: anchorRef,
    onClick: () => setMenuOpen(true),
    startIcon: /*#__PURE__*/React.createElement(MoreIcon, null),
    className: mobileButtonClass
  }, "More") : /*#__PURE__*/React.createElement(Button, {
    ref: anchorRef,
    onClick: () => setMenuOpen(true),
    startIcon: /*#__PURE__*/React.createElement(SettingsIcon, null),
    className: classes.settingsButton
  }, "Settings"), /*#__PURE__*/React.createElement(MenuContainer, {
    open: menuOpen,
    onClose: () => setMenuOpen(isOpen => !isOpen),
    anchorEl: anchorRef.current,
    getContentAnchorEl: null,
    anchorOrigin: {
      vertical: 'top',
      horizontal: isMobile ? 'left' : 'right'
    },
    transformOrigin: {
      vertical: 0,
      horizontal: 'center'
    }
  }, /*#__PURE__*/React.createElement(MenuItem, {
    onClick: () => setAboutOpen(true)
  }, /*#__PURE__*/React.createElement(Typography, {
    variant: "body1"
  }, "About")), /*#__PURE__*/React.createElement(MenuItem, {
    onClick: () => setDeviceSettingsOpen(true)
  }, /*#__PURE__*/React.createElement(Typography, {
    variant: "body1"
  }, "Audio and Video Settings")), roomType !== 'peer-to-peer' && roomType !== 'go' && /*#__PURE__*/React.createElement(MenuItem, {
    onClick: () => setConnectionSettingsOpen(true)
  }, /*#__PURE__*/React.createElement(Typography, {
    variant: "body1"
  }, "Connection Settings"))), /*#__PURE__*/React.createElement(AboutDialog, {
    open: aboutOpen,
    onClose: () => {
      setAboutOpen(false);
      setMenuOpen(false);
    }
  }), /*#__PURE__*/React.createElement(DeviceSelectionDialog, {
    open: deviceSettingsOpen,
    onClose: () => {
      setDeviceSettingsOpen(false);
      setMenuOpen(false);
    }
  }), /*#__PURE__*/React.createElement(ConnectionOptionsDialog, {
    open: connectionSettingsOpen,
    onClose: () => {
      setConnectionSettingsOpen(false);
      setMenuOpen(false);
    }
  }));
}