import React from 'react';
import AttachVisibilityHandler from './AttachVisibilityHandler';
import useLocalVideoToggle from '../../../hooks/useLocalVideoToggle/useLocalVideoToggle';
import { render } from '@testing-library/react';
import * as utils from '../../../utils';
import useVideoContext from '../../../hooks/useVideoContext/useVideoContext';
jest.mock('../../../hooks/useVideoContext/useVideoContext');
jest.mock('../../../hooks/useLocalVideoToggle/useLocalVideoToggle');
const mockUseVideoContext = useVideoContext;
const mockUseLocalVideoToggle = useLocalVideoToggle;
const mockToggleVideoEnabled = jest.fn();
Object.defineProperty(document, 'visibilityState', {
  value: '',
  writable: true
});
mockUseLocalVideoToggle.mockImplementation(() => [true, mockToggleVideoEnabled]);
mockUseVideoContext.mockImplementation(() => ({
  room: {}
}));
describe('the AttachVisibilityHandler component', () => {
  describe('when isMobile is false', () => {
    it('should not add a visibilitychange event handler to the document', () => {
      // @ts-ignore
      utils.isMobile = false;
      jest.spyOn(document, 'addEventListener');
      render( /*#__PURE__*/React.createElement(AttachVisibilityHandler, null));
      expect(document.addEventListener).not.toHaveBeenCalled();
    });
  });
  describe('when isMobile is true', () => {
    beforeAll(() => {
      // @ts-ignore
      utils.isMobile = true;
    });
    beforeEach(jest.clearAllMocks);
    it('should add a visibilitychange event handler to the document', () => {
      jest.spyOn(document, 'addEventListener');
      render( /*#__PURE__*/React.createElement(AttachVisibilityHandler, null));
      expect(document.addEventListener).toHaveBeenCalled();
    });
    it('should correctly toggle video when it is already enabled', () => {
      render( /*#__PURE__*/React.createElement(AttachVisibilityHandler, null)); // @ts-ignore

      document.visibilityState = 'hidden';
      document.dispatchEvent(new Event('visibilitychange'));
      expect(mockToggleVideoEnabled).toHaveBeenCalled();
      jest.clearAllMocks(); // @ts-ignore

      document.visibilityState = 'visible';
      document.dispatchEvent(new Event('visibilitychange'));
      expect(mockToggleVideoEnabled).toHaveBeenCalled();
    });
    it('should correctly toggle video when it is already disabled', () => {
      mockUseLocalVideoToggle.mockImplementation(() => [false, mockToggleVideoEnabled]);
      render( /*#__PURE__*/React.createElement(AttachVisibilityHandler, null)); // @ts-ignore

      document.visibilityState = 'hidden';
      document.dispatchEvent(new Event('visibilitychange'));
      expect(mockToggleVideoEnabled).not.toHaveBeenCalled();
      jest.clearAllMocks(); // @ts-ignore

      document.visibilityState = 'visible';
      document.dispatchEvent(new Event('visibilitychange'));
      expect(mockToggleVideoEnabled).not.toHaveBeenCalled();
    });
    it('should not add a visibilitychange event handler to the document when a room does not exist', () => {
      mockUseVideoContext.mockImplementationOnce(() => ({}));
      jest.spyOn(document, 'addEventListener');
      render( /*#__PURE__*/React.createElement(AttachVisibilityHandler, null));
      expect(document.addEventListener).not.toHaveBeenCalled();
    });
  });
});